#
# spec file for package octave-forge-control
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  control
Name:           octave-forge-%{octpkg}
Version:        4.0.1
Release:        1.2
Summary:        Computer-Aided Control System Design (CACSD) Tools
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gnu-octave.github.io/packages/%{octpkg}/
Source0:        https://github.com/gnu-octave/pkg-control/releases/download/%{octpkg}-%{version}/%{octpkg}-%{version}.tar.gz
BuildRequires:  blas-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 4.0.0

%description
Computer-Aided Control System Design (CACSD) Tools for GNU Octave, based
on the proven SLICOT Library.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Tue Jun  4 2024 ming li <mli@suse.com>
- Update to version 4.0.1:
  * warning messages do not include trace information anymore
  * mktito: changed name of inputs and outputs for
    compatibility (bug #63736)
  * more robust test using Markov parameters for several
    model reduction routines (bug #65218)
  * fix graphic styles in pzmap (bug #57716) -doc_control
    ('license') displays license and copyright information
* Fri Jan  5 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.6.1:
  * use current version of the SLICOT-Reference routines v5.8
    from Github
  * fixed phase in bode plot for system with poles/zeros at
    the origin
  * fixed duration of time responses like step for systems with
    oscillations ans improved graphical output
* Wed Jan  3 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.6.1:
  + Bugfix: numeric constants are converted into proper lti
    systems before being interconnected to discrete time-systems
- Update to version 3.6.0:
  + zgrid: new function for grid lines with constant eigenfrequency
    and damping for discrete-time pole/zero maps
  + pzamp: added unit circle (for discrete-time) systems and axes
    to the pole/zero maps
  + allow discrete-time purely static gain systems with a
    sampling time
  + added metainfo file octave-control.metainfo.xml
- Update to version 3.5.2:
  + fix build errors when installing in Octave 6
- Update to version 3.5.1:
  + fix build errors when installing in Octave 9
  + more robust tests for some model reduction and identification
    functions
* Wed Feb 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.4.0:
  * Fix lyapunov equ. in dlyap if B is non-symmetric (bug #49801).
  * Declare tf([1],[1]) as static gain.
  * Returned num and den of tfdate have same length (bug #43947).
  * Fixes for Octave 7.1.0: removed deprecated .+ operator and
    unsupported plot style.
* Wed Sep 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3.1:
  * Fixed time response for first order systems.
- Changes from version 3.3.0:
  * New function rlocusx providing gain, damping and frequency for
    selected poles together with the possibility to generate open
    loop bode plots and simulations of the closed loop for
    selected closed loop poles.
  * Fixed several issues in bode, c2d, lsim and step.
  * Fixed issues in legends of time and frequency responses when
  * requested for multiple systems.
  * Fixed usage of deprecated LAPACK routines.
  * Added discretization method 'foh' to c2d.
  * Added tests for c2d with 'foh' and to dlyapchol.
  * Fixed transposing a tfploy.
- Drop control-gcc-errors.patch: No longer required as fixed
  upstream.
* Tue Nov 26 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.2.0
  * new function sgrid
  * New function: ss2ss
  * Fixed many warnings
  * added demos to rlocus, pzmap, bode, nichols, nyquist, impulse, lsim,
    ramp and step
  * improved pzmap to plot with only zeros
- Update to version 3.1.0
  * New function: damp
  * Changed nelem to numel and length to numel to remove the warnings
    during installation.
  * The Impulse section has been rewritten, and a new file - imp_invar.m -
    added. The old system tried to use the "zoh" to get an impulse response
    but that is impossible.
  * The new function "imp_invar.m" converts a Laplace tranfer function
    to a discrete tranfer function.
  * New functions: acker, dsort, esort.
  * Function lsim now plots inputs as well.
  * Class 'ss' should now work with complex inputs.
  * Extend nyquist plots.
  * Fixed warnings with newer Octave versions.
* Sat Oct 31 2015 dmitry_r@opensuse.org
- Update to version 3.0.0
  * Substantial parts of the most vital internals have been rewritten
    and streamlined in order to improve compatibility and reliability.
  * LTI models:
    Improved handling of key-value pairs in all constructors for LTI models.
    Support inheritance of LTI properties in many variations.
    Accept [] as an alias for unspecified sampling time (Ts = -1).
    Automatic vector expansion for input and output names.
  * dss
    Fixed a long-standing but undiscovered bug where 'dss (sys)'
    overwrites sys.e with an identity matrix even if sys.e was not empty.
  * ss
    Support for the special cases has been added.
  * tf, zpk, filt
    Restrict transfer function variable to the candidates 's', 'p' for
    continuous-time and 'z', 'q', 'z^-1', 'q^-1' for discrete-time models.
  * bode, bodemag, nichols, nyquist, sigma
    It is now possible to specify a frequency vector of length 1.
  * step, impulse, initial, ramp
    The time response functions now raise an error or warning if invalid
    arguments are passed to them.  As it was the case for frequency response
    functions, they used to simply ignore invalid arguments.
  * lsim
    Support logical arrays as input signal.  Before, logical arrays were
    simply ignored without notice, which could lead to unexpected results.
    Additionally, lsim received the same improvements as the other time and
    frequency response functions regarding invalid arguments.
  * pzmap
    Improved argument checks.
  * augstate
    New function for state-space models.  Adds the state vector to the output
    vector.
  * connect
    The function no longer raises an error for name-based interconnections
    if some systems have common input names and one of these inputs are to
    be kept.
  * estim
    Add input/output/state names to the returned system.  Support name-based
    selection of inputs (arguments 'sensors' and 'known').
  * * sumblk
    Add signal names as input/output groups if argument  n > 1.
  * * minreal
    If state-space models already have a minimal realization, then no state
    transformations are applied to the returned model.
* Sat Oct  3 2015 dmitry_r@opensuse.org
- Update to versiob 2.8.5
  * Bug fixes
  * Matlab compatibility improvements
* Wed Sep  9 2015 dmitry_r@opensuse.org
- Update to version 2.8.4
  * Bug fixes and minor changes
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.8.3
  * Bug fixes and minor changes
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Update to version 2.8.2
  * Bugfix release
* Mon May  4 2015 dmitry_r@opensuse.org
- Update to version 2.8.1
  * tf
  - Revamped the modifications of TB01ZD from control version 2.8.0.
    The function now uses LAPACK routines to find the maximum norm element.
  - Improved error handling when converting state-space models.
* Tue Apr  7 2015 dmitry_r@opensuse.org
- Update to version 2.8.0
  * zero
    Compatibility fix in the C++ oct-file to support the upcoming Octave 4.0.
  * isminimumphase
    Reverted changes from control-2.6.6.  According to the
    definition of Byrnes/Isidori, the function tests whether the system
    has asymptotically stable zero dynamics. The poles are not tested.
  * series
    Fixed a bug which gave unnecessary error messages when the
    function is called with 4 arguments.
  * tf
    Resolved issues in MIMO state-space to transfer function
    conversion by implementing a more robust algorithm in SLICOT
    routine TB01ZD.
  * Support for 64bit indexing option.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.6.6
- Fix GCC errors: no return in non-void function
  * control-gcc-errors.patch
